@@ -5,6 +5,6 @@ ORDER.default <- function(x, ..., na.last = TRUE, decreasing = FALSE)
   order(x, ..., na.last = na.last, decreasing = decreasing)
 
 ORDER.timeDate <- function(x, ...) {
-  stopifnot(require("fCalendar"))
+  stopifnot(require("timeDate"))
   order(as.POSIXct(x), ...)
 }
